"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var TSCActivity = com.example.tscdll.TSCActivity;
var Bitmap = android.graphics.Bitmap;
var Canvas = android.graphics.Canvas;
var Paint = android.graphics.Paint;
var Rect = android.graphics.Rect;
var Color = android.graphics.Color;
var TextPaint = android.text.TextPaint;
var Typeface = android.graphics.Typeface;
var FileOutputStream = java.io.FileOutputStream;
var Environment = android.os.Environment;
var File = java.io.File;
var Path = android.graphics.Path;
var utils = require("tns-core-modules/utils/utils");
var application = require("tns-core-modules/application");
var ACCESS_LOCATION_PERMISSION_REQUEST_CODE = 222;
var ACTION_REQUEST_ENABLE_BLUETOOTH_REQUEST_CODE = 223;
var AppPackageName = useAndroidX() ? global.androidx.core.app : android.support.v4.app;
var LocationPermission = useAndroidX()
    ? android.Manifest.permission.ACCESS_FINE_LOCATION
    : android.Manifest.permission.ACCESS_COARSE_LOCATION;
function useAndroidX() {
    return global.androidx && global.androidx.appcompat;
}
var Mht = (function () {
    function Mht() {
        this.bluetoothManager = utils.ad
            .getApplicationContext()
            .getSystemService(android.content.Context.BLUETOOTH_SERVICE);
        this.adapter = this.bluetoothManager.getAdapter();
    }
    Object.defineProperty(Mht.prototype, "enabled", {
        get: function () {
            if (this.adapter !== null && this.adapter.isEnabled()) {
                return true;
            }
            else {
                return false;
            }
        },
        enumerable: true,
        configurable: true
    });
    Mht.prototype.drawCenterCanvas = function (canvas, paint, text) {
        var r = new Rect();
        canvas.getClipBounds(r);
        var cHeight = r.height();
        var cWidth = r.width();
        paint.setTextAlign(Paint.Align.LEFT);
        paint.getTextBounds(text, 0, text.length, r);
        var x = cWidth / 2 - r.width() / 2 - r.left;
        var y = cHeight / 2 + r.height() / 2 - r.bottom;
        canvas.drawText(text, x, y, paint);
    };
    Mht.prototype.drawCenterHorizontal = function (canvas, paint, vertical, text) {
        var r = new Rect();
        canvas.getClipBounds(r);
        var cWidth = r.width();
        paint.setTextAlign(Paint.Align.LEFT);
        paint.getTextBounds(text, 0, text.length, r);
        var x = cWidth / 2 - r.width() / 2 - r.left;
        canvas.drawText(text, x, vertical, paint);
    };
    Mht.prototype.drawCenterHorizontalOffset = function (canvas, paint, vertical, text, offset) {
        var r = new Rect();
        canvas.getClipBounds(r);
        var cWidth = r.width();
        paint.setTextAlign(Paint.Align.LEFT);
        paint.getTextBounds(text, 0, text.length, r);
        var x = cWidth / 2 - r.width() / 2 - r.left;
        canvas.drawText(text, x + offset, vertical, paint);
    };
    Mht.prototype.saveBitmapToSD = function (bitmap) {
        try {
            var sd = Environment.getExternalStorageDirectory();
            var dest = new File(sd, "nativescript-mht-printer.png");
            var out = new FileOutputStream(dest);
            bitmap.compress(Bitmap.CompressFormat.PNG, 100, out);
            out.flush();
            out.close();
        }
        catch (e) {
            console.log(e);
            return false;
        }
        return true;
    };
    Mht.prototype.drawArrow = function (canvas, paint, x, y) {
        var mPath = new Path();
        mPath.moveTo(x, y + 20);
        mPath.lineTo(x + 10, y + 20);
        mPath.lineTo(x + 10, y + 10);
        mPath.lineTo(x + 20, y + 25);
        mPath.lineTo(x + 10, y + 40);
        mPath.lineTo(x + 10, y + 30);
        mPath.lineTo(x, y + 30);
        mPath.lineTo(x, y + 20);
        mPath.close();
        canvas.drawPath(mPath, paint);
    };
    Mht.prototype._isEnabled = function () {
        return this.adapter && this.adapter.isEnabled();
    };
    Mht.prototype._getContext = function () {
        var ctx = java.lang.Class.forName('android.app.AppGlobals')
            .getMethod('getInitialApplication', null)
            .invoke(null, null);
        if (ctx) {
            return ctx;
        }
        return java.lang.Class.forName('android.app.ActivityThread')
            .getMethod('currentApplication', null)
            .invoke(null, null);
    };
    Mht.prototype._getActivity = function () {
        var _this = this;
        var activity = application.android.foregroundActivity || application.android.startActivity;
        if (activity === null) {
            setTimeout(function () {
                _this._getActivity();
            }, 250);
            return;
        }
        else {
            return activity;
        }
    };
    Mht.prototype.requestLocationPermission = function (callback) {
        var _this = this;
        return new Promise(function (resolve, reject) {
            var permissionCb = function (args) {
                if (args.requestCode === ACCESS_LOCATION_PERMISSION_REQUEST_CODE) {
                    application.android.off(application.AndroidApplication.activityRequestPermissionsEvent, permissionCb);
                    for (var i = 0; i < args.permissions.length; i++) {
                        if (args.grantResults[i] === android.content.pm.PackageManager.PERMISSION_DENIED) {
                            reject('Permission denied');
                            return;
                        }
                    }
                    if (callback) {
                        callback();
                    }
                    resolve();
                }
            };
            application.android.on(application.AndroidApplication.activityRequestPermissionsEvent, permissionCb);
            AppPackageName.ActivityCompat.requestPermissions(_this._getActivity(), [LocationPermission], ACCESS_LOCATION_PERMISSION_REQUEST_CODE);
        });
    };
    Mht.prototype.enable = function () {
        return new Promise(function (resolve, reject) {
            try {
                var onBluetoothEnableResult_1 = function (args) {
                    if (args.requestCode === ACTION_REQUEST_ENABLE_BLUETOOTH_REQUEST_CODE) {
                        try {
                            application.android.off(application.AndroidApplication.activityResultEvent, onBluetoothEnableResult_1);
                            if (args.resultCode === android.app.Activity.RESULT_OK) {
                                resolve(true);
                            }
                            else {
                                resolve(false);
                            }
                        }
                        catch (ex) {
                            application.android.off(application.AndroidApplication.activityResultEvent, onBluetoothEnableResult_1);
                            reject(ex);
                            return;
                        }
                    }
                    else {
                        application.android.off(application.AndroidApplication.activityResultEvent, onBluetoothEnableResult_1);
                        resolve(false);
                        return;
                    }
                };
                application.android.on(application.AndroidApplication.activityResultEvent, onBluetoothEnableResult_1);
                var intent = new android.content.Intent(android.bluetooth.BluetoothAdapter.ACTION_REQUEST_ENABLE);
                var activity = application.android.foregroundActivity || application.android.startActivity;
                activity.startActivityForResult(intent, ACTION_REQUEST_ENABLE_BLUETOOTH_REQUEST_CODE);
            }
            catch (ex) {
                reject(ex);
            }
        });
    };
    Mht.prototype.isBluetoothEnabled = function () {
        var _this = this;
        return new Promise(function (resolve, reject) {
            try {
                resolve(_this._isEnabled());
            }
            catch (ex) {
                reject(ex);
            }
        });
    };
    Mht.prototype.printServiceLabel = function (port, serviceId, labelNumber, clientName) {
        if (!port || !serviceId || !labelNumber || !clientName) {
            return new Promise(function (resolve, reject) { reject("Error"); });
        }
        var serviceBitmap = Bitmap.createBitmap(180, 180, Bitmap.Config.ARGB_8888);
        var canvas = new Canvas(serviceBitmap);
        canvas.rotate(180, 90, 90);
        canvas.drawRGB(255, 255, 255);
        var tpServiceId = new TextPaint();
        var tpLabelNumber = new TextPaint();
        var tpClientName = new TextPaint();
        var linePaint = new Paint(Color.BLACK);
        canvas.drawLine(20, 0, 20, 180, linePaint);
        tpServiceId.setAntiAlias(false);
        tpServiceId.setTextSize(40);
        tpServiceId.setTypeface(Typeface.create(Typeface.DEFAULT, Typeface.BOLD));
        tpServiceId.setColor(Color.BLACK);
        tpLabelNumber.setAntiAlias(false);
        tpLabelNumber.setTextSize(40);
        tpLabelNumber.setTypeface(Typeface.create(Typeface.DEFAULT, Typeface.BOLD_ITALIC));
        tpLabelNumber.setColor(Color.BLACK);
        tpClientName.setAntiAlias(false);
        tpClientName.setTextSize(14);
        tpClientName.setColor(Color.BLACK);
        this.drawArrow(canvas, linePaint, 0, 0);
        this.drawArrow(canvas, linePaint, 0, 70);
        this.drawArrow(canvas, linePaint, 0, 140);
        this.drawCenterHorizontalOffset(canvas, tpServiceId, 40, serviceId, 10);
        this.drawCenterHorizontalOffset(canvas, tpLabelNumber, 100, "#" + labelNumber, 10);
        this.drawCenterHorizontalOffset(canvas, tpClientName, 170, clientName, 10);
        canvas.save();
        return new Promise(function (resolve, reject) {
            var tscActivity = new TSCActivity();
            tscActivity.openport(port);
            tscActivity.sendcommand("SIZE 58 mm, 25 mm\r\n");
            tscActivity.clearbuffer();
            tscActivity.sendcommand("SPEED 4\r\n");
            tscActivity.sendcommand("CODEPAGE UTF-8\r\n");
            tscActivity.sendcommandUTF8("DENSITY 4\r\n");
            tscActivity.sendcommandUTF8("DIRECTION 1\r\n");
            tscActivity.sendbitmap(180, 0, serviceBitmap);
            tscActivity.qrcode(180, 180, "M", "8", "A", "180", "M1", "S7", serviceId);
            tscActivity.printlabel(1, 1);
            var res = tscActivity.closeport(5000);
            if (res == "1") {
                resolve("Printed");
            }
            else {
                reject("Print Error");
            }
        });
    };
    Mht.prototype.printClientLabel = function (port, serviceId, clientUrl, clientName, clientPhone, clientEmail, clientPass) {
        if (!port || !serviceId || !clientUrl || !clientName || !clientPhone || !clientEmail || !clientPass) {
            return new Promise(function (resolve, reject) { reject("Error"); });
        }
        var productBitmap = Bitmap.createBitmap(180, 180, Bitmap.Config.ARGB_8888);
        var canvas = new Canvas(productBitmap);
        canvas.drawRGB(255, 255, 255);
        var tpServiceId = new TextPaint();
        var tpClient = new TextPaint();
        tpServiceId.setAntiAlias(false);
        tpServiceId.setTextSize(40);
        tpServiceId.setTypeface(Typeface.create(Typeface.DEFAULT, Typeface.BOLD));
        tpServiceId.setColor(Color.BLACK);
        tpClient.setAntiAlias(false);
        tpClient.setTextSize(20);
        tpClient.setColor(Color.BLACK);
        this.drawCenterHorizontal(canvas, tpServiceId, 40, serviceId);
        this.drawCenterHorizontal(canvas, tpClient, 80, clientName);
        this.drawCenterHorizontal(canvas, tpClient, 110, clientPhone);
        this.drawCenterHorizontal(canvas, tpClient, 140, clientEmail);
        this.drawCenterHorizontal(canvas, tpClient, 170, clientPass);
        canvas.save();
        return new Promise(function (resolve, reject) {
            var tscActivity = new TSCActivity();
            tscActivity.openport(port);
            tscActivity.sendcommand("SIZE 58 mm, 25 mm\r\n");
            tscActivity.clearbuffer();
            tscActivity.sendcommand("SPEED 4\r\n");
            tscActivity.sendcommand("CODEPAGE UTF-8\r\n");
            tscActivity.sendcommandUTF8("DENSITY 4\r\n");
            tscActivity.sendcommandUTF8("DIRECTION 1\r\n");
            tscActivity.sendbitmap(180, 0, productBitmap);
            tscActivity.qrcode(10, 10, "M", "2", "A", "0", "M1", "S7", clientUrl);
            tscActivity.printlabel(1, 1);
            var res = tscActivity.closeport(5000);
            if (res == "1") {
                resolve("Printed");
            }
            else {
                reject("Print Error");
            }
        });
    };
    Mht.prototype.printProductLabel = function (port, sku, price, brand, model) {
        if (!port || !sku || !price || !brand || !model) {
            return new Promise(function (resolve, reject) { reject("Error"); });
        }
        var productBitmap = Bitmap.createBitmap(180, 180, Bitmap.Config.ARGB_8888);
        var canvas = new Canvas(productBitmap);
        canvas.drawRGB(255, 255, 255);
        var tpSKU = new TextPaint();
        var tpBrand = new TextPaint();
        var tpPrice = new TextPaint();
        tpSKU.setAntiAlias(false);
        tpSKU.setTextSize(40);
        tpSKU.setTypeface(Typeface.create(Typeface.DEFAULT, Typeface.BOLD));
        tpSKU.setColor(Color.BLACK);
        tpPrice.setAntiAlias(false);
        tpPrice.setTextSize(30);
        tpPrice.setColor(Color.BLACK);
        tpBrand.setAntiAlias(false);
        tpBrand.setTextSize(20);
        tpBrand.setColor(Color.BLACK);
        this.drawCenterHorizontal(canvas, tpSKU, 40, sku);
        this.drawCenterHorizontal(canvas, tpPrice, 100, price);
        this.drawCenterHorizontal(canvas, tpBrand, 140, brand.toUpperCase());
        this.drawCenterHorizontal(canvas, tpBrand, 170, model.toUpperCase());
        canvas.save();
        return new Promise(function (resolve, reject) {
            var tscActivity = new TSCActivity();
            tscActivity.openport(port);
            tscActivity.sendcommand("SIZE 58 mm, 25 mm\r\n");
            tscActivity.clearbuffer();
            tscActivity.sendcommand("SPEED 4\r\n");
            tscActivity.sendcommand("CODEPAGE UTF-8\r\n");
            tscActivity.sendcommandUTF8("DENSITY 4\r\n");
            tscActivity.sendcommandUTF8("DIRECTION 1\r\n");
            tscActivity.sendbitmap(180, 0, productBitmap);
            tscActivity.qrcode(10, 10, "M", "8", "A", "0", "M1", "S7", sku);
            tscActivity.printlabel(1, 1);
            var res = tscActivity.closeport(5000);
            if (res == "1") {
                resolve("Printed");
            }
            else {
                reject("Print Error");
            }
        });
    };
    Mht.prototype.printText = function (port, text) {
        if (!port || !text) {
            return new Promise(function (resolve, reject) { reject("Error"); });
        }
        var textBitmap = Bitmap.createBitmap(180, 180, Bitmap.Config.ARGB_8888);
        var canvas = new Canvas(textBitmap);
        var tpText = new TextPaint();
        tpText.setAntiAlias(false);
        tpText.setTextSize(40);
        tpText.setTypeface(Typeface.create(Typeface.DEFAULT, Typeface.BOLD));
        tpText.setColor(Color.BLACK);
        canvas.drawRGB(255, 255, 255);
        this.drawCenterHorizontal(canvas, tpText, 100, text);
        canvas.save();
        return new Promise(function (resolve, reject) {
            var tscActivity = new TSCActivity();
            tscActivity.openport(port);
            tscActivity.sendcommand("SIZE 58 mm, 25 mm\r\n");
            tscActivity.clearbuffer();
            tscActivity.sendcommand("SPEED 4\r\n");
            tscActivity.sendcommand("DENSITY 4\r\n");
            tscActivity.sendcommand("DIRECTION 1\r\n");
            tscActivity.sendcommand("CODEPAGE UTF-8\r\n");
            tscActivity.sendbitmap(0, 0, textBitmap);
            tscActivity.printlabel(1, 1);
            var res = tscActivity.closeport(5000);
            if (res == "1") {
                resolve("Printed");
            }
            else {
                reject("Print Error");
            }
        });
    };
    return Mht;
}());
exports.Mht = Mht;
//# sourceMappingURL=mht-printer.android.js.map